@@ -15,23 +15,6 @@
 #' is created_ and its value is used to configure the workers.
 #' The function should return any of the above types.
 #' 
-#' @param revtunnel If TRUE, reverse SSH tunneling is used for the
-#' PSOCK cluster nodes to connect back to the master \R process.  This
-#' avoids the hassle of firewalls, port forwarding and having to know
-#' the internal / public IP address of the master \R session.
-#' 
-#' @param user (optional) The user name to be used when communicating
-#' with another host.
-#' 
-#' @param master (optional) The hostname or IP address of the master
-#' machine running this node.
-#' 
-#' @param homogeneous If TRUE, all cluster nodes is assumed to use the
-#' same path to \file{Rscript} as the main \R session.  If FALSE, the
-#' it is assumed to be on the PATH for each node.
-#' If NULL, then [parallelly::makeClusterPSOCK()] will decide on TRUE
-#' or FALSE depending on `workers`.
-#'
 #' @return
 #' `ClusterFuture()` returns an object of class `ClusterFuture`.
 #'
@@ -45,7 +28,7 @@
 #' @importFrom digest digest
 #' @name ClusterFuture-class
 #' @keywords internal
-ClusterFuture <- function(expr = NULL, substitute = TRUE, envir = parent.frame(), globals = TRUE, packages = NULL, local = !persistent, persistent = FALSE, workers = NULL, user = NULL, master = NULL, revtunnel = TRUE, homogeneous = NULL, ...) {
+ClusterFuture <- function(expr = NULL, substitute = TRUE, envir = parent.frame(), globals = TRUE, packages = NULL, local = !persistent, persistent = FALSE, workers = NULL, ...) {
   if (substitute) expr <- substitute(expr)
   
   stop_if_not(is.logical(persistent), length(persistent) == 1L,
@@ -66,9 +49,9 @@ ClusterFuture <- function(expr = NULL, substitute = TRUE, envir = parent.frame()
   ## which should be passed to makeClusterPSOCK()?
   future_args <- !is.element(names(args), makeClusterPSOCK_args())
   
-  future <- do.call(MultiprocessFuture, args = c(list(expr = quote(expr), substitute = FALSE, envir = envir, globals = globals, packages = packages, local = local, node = NA_integer_, persistent = persistent), args[future_args]))
+  future <- do.call(MultiprocessFuture, args = c(list(expr = quote(expr), substitute = FALSE, envir = envir, globals = globals, packages = packages, local = local, node = NA_integer_, persistent = persistent), args[future_args]), quote = FALSE)
 
-  future <- do.call(as_ClusterFuture, args = c(list(future, workers = workers, user = user, master = master, revtunnel = revtunnel, homogeneous = homogeneous), args[!future_args]))
+  future <- do.call(as_ClusterFuture, args = c(list(future, workers = workers), args[!future_args]), quote = TRUE)
 
   future
 }
@@ -508,7 +491,7 @@ receiveMessageFromWorker <- function(future, ...) {
 }
 
 
-requestNode <- function(await, workers, timeout = getOption("future.wait.timeout", 30 * 24 * 60 * 60), delta = getOption("future.wait.interval", 0.2), alpha = getOption("future.wait.alpha", 1.01)) {
+requestNode <- function(await, workers, timeout = getOption("future.wait.timeout", 30 * 24 * 60 * 60), delta = getOption("future.wait.interval", 0.01), alpha = getOption("future.wait.alpha", 1.01)) {
   debug <- getOption("future.debug", FALSE)
   
   stop_if_not(inherits(workers, "cluster"))
@@ -557,7 +540,8 @@ requestNode <- function(await, workers, timeout = getOption("future.wait.timeout
   if (!finished) {
     msg <- sprintf("TIMEOUT: All %d cluster nodes are still occupied after %s (polled %d times)", total, format(round(dt, digits = 2L)), iter)
     if (debug) mdebug(msg)
-    stop(msg)
+    ex <- FutureError(msg, future = future)
+    stop(ex)
   }
 
   ## Find which node is available
@@ -713,7 +697,7 @@ post_mortem_cluster_failure <- function(ex, when, node, future) {
   
   ## (a) Process information on the worker, if available
   pid <- node$session_info$process$pid
-  pid_info <- if (is.numeric(pid)) sprintf("PID %g", pid) else NULL
+  pid_info <- if (is.numeric(pid)) sprintf("PID %.0f", pid) else NULL
 
   ## (b) Host information on the worker, if available
   ##     AD HOC: This assumes that the worker has a hostname, which is not
