@@ -399,20 +399,6 @@ parseCmdArgs <- function() {
 
 
 
-## A version of base::sample() that does not change .Random.seed
-stealth_sample <- function(x, size = length(x), replace = FALSE, ...) {
-  oseed <- .GlobalEnv$.Random.seed
-  on.exit({
-    if (is.null(oseed)) {
-      rm(list = ".Random.seed", envir = .GlobalEnv, inherits = FALSE)
-    } else {
-      .GlobalEnv$.Random.seed <- oseed
-    }
-  })
-  sample(x, size = size, replace = replace, ...)
-}
-
-
 myExternalIP <- local({
   ip <- NULL
   function(force = FALSE, random = TRUE, mustWork = TRUE) {
@@ -943,7 +929,7 @@ pid_exists <- local({
     ## on Sys.getpid() once found a match while the second time none.
     for (kk in 1:5) {
       res <- tryCatch({
-        args = c("/FI", shQuote(sprintf("PID eq %g", pid)), "/NH")
+        args = c("/FI", shQuote(sprintf("PID eq %.0f", pid)), "/NH")
         out <- system2("tasklist", args = args, stdout = TRUE)
         if (debug) {
           cat(sprintf("Call: tasklist %s\n", paste(args, collapse = " ")))
@@ -957,7 +943,7 @@ pid_exists <- local({
           print(out)
           str(out)
         }
-        out <- grepl(sprintf(" %g ", pid), out)
+        out <- grepl(sprintf(" %.0f ", pid), out)
         if (debug) {
           cat("Contains PID: ", paste(out, collapse = ", "), "\n", sep = "")
         }
@@ -1147,6 +1133,44 @@ supports_omp_threads <- function(assert = FALSE, debug = getOption("future.debug
   res
 }
 
+
+## On MS Windows, support for capturing UTF8 symbols was added in R 4.2.0,
+## but it requires a certain setup.
+can_capture_utf8 <- if (.Platform$OS.type == "windows") {
+  if (getRversion() >= "4.2.0") {
+    local({
+      truth <- "\u2713" ## checkmark
+      truth_raw <- charToRaw(truth)
+      success <- NA
+      
+      function() {
+        if (is.na(success)) {
+          con <- rawConnection(raw(), open = "w")
+          on.exit(close(con))
+          sink(file = con)
+          sunk <- TRUE
+          on.exit(if (sunk) sink(NULL), add = TRUE)
+    
+          ## Output UTF-symbol checkmark
+          cat(truth)
+    
+          sink(NULL)
+          sunk <- FALSE
+          output <- rawConnectionValue(con)
+          close(con)
+          on.exit()
+          success <<- identical(output, truth_raw)
+        }
+        success
+      }
+    })
+  } else {
+    function() FALSE
+  }
+} else {
+  function() TRUE
+}
+
 ## https://github.com/HenrikBengtsson/future/issues/473
 adhoc_native_to_utf8 <- function(x) {
   code <- gsub("<U[+]([[:alnum:]]+)>", "\\\\u\\1", x)
