@@ -1,3 +1,7 @@
+## Load namespace already here; it'll set some options based on
+## environment variables
+loadNamespace("future")
+
 ## Record original state
 ovars <- ls()
 oenvs <- oenvs0 <- Sys.getenv()
@@ -22,22 +26,22 @@ oopts <- options(
 ## Comment: The below should be set automatically whenever the future package
 ## is loaded and 'R CMD check' runs.  The below is added in case R is changed
 ## in the future and we fail to detect 'R CMD check'.
-Sys.setenv(R_FUTURE_MAKENODEPSOCK_CONNECTTIMEOUT = 2 * 60)
-Sys.setenv(R_FUTURE_MAKENODEPSOCK_TIMEOUT = 2 * 60)
+Sys.setenv(R_PARALLELLY_MAKENODEPSOCK_CONNECTTIMEOUT = 2 * 60)
+Sys.setenv(R_PARALLELLY_MAKENODEPSOCK_TIMEOUT = 2 * 60)
+Sys.setenv(R_PARALLELLY_MAKENODEPSOCK_SESSIONINFO_PKGS = TRUE)
 Sys.setenv(R_FUTURE_WAIT_INTERVAL = 0.01) ## 0.01s (instead of default 0.2s)
-Sys.setenv(R_FUTURE_MAKENODEPSOCK_SESSIONINFO_PKGS = TRUE)
 
 ## Label PSOCK cluster workers (to help troubleshooting)
 test_script <- grep("[.]R$", commandArgs(), value = TRUE)[1]
 if (is.na(test_script)) test_script <- "UNKNOWN"
 worker_label <- sprintf("future/tests/%s:%s:%s:%s", test_script, Sys.info()[["nodename"]], Sys.info()[["user"]], Sys.getpid())
-Sys.setenv(R_FUTURE_MAKENODEPSOCK_RSCRIPT_LABEL = worker_label)
+Sys.setenv(R_PARALLELLY_MAKENODEPSOCK_RSCRIPT_LABEL = worker_label)
 
 ## Reset the following during testing in case
 ## they are set on the test system
 oenvs2 <- Sys.unsetenv(c(
-  "R_FUTURE_AVAILABLECORES_SYSTEM",
-  "R_FUTURE_AVAILABLECORES_FALLBACK",
+  "R_PARALLELLY_AVAILABLECORES_SYSTEM",
+  "R_PARALLELLY_AVAILABLECORES_FALLBACK",
   ## SGE
   "NSLOTS", "PE_HOSTFILE",
   ## Slurm
@@ -92,16 +96,22 @@ attachLocally <- function(x, envir = parent.frame()) {
   }
 }
 
-supportedStrategies <- function(cores = 1L, excl = c("multiprocess", "cluster"), ...) {
+supportedStrategies <- function(cores = NA_integer_, excl = "cluster", ...) {
   strategies <- future:::supportedStrategies(...)
   strategies <- setdiff(strategies, excl)
-  if (cores == 1L) {
-    strategies <- setdiff(strategies, c("multicore", "multisession",
-                                        "multiprocess"))
-  } else {
-    strategies <- setdiff(strategies,
-                          c("sequential", "uniprocess", "eager", "lazy"))
+  
+  if (!is.na(cores)) {
+    if (cores == 1L) {
+      strategies <- setdiff(strategies, c("multicore", "multisession"))
+    } else if (cores > 1L) {
+      strategies <- setdiff(strategies,
+                            c("sequential", "uniprocess", "eager", "lazy"))
+    }
   }
+  
+  ## Don't test deprecated 'multiprocess'
+  strategies <- setdiff(strategies, "multiprocess")
+  
   strategies
 }
 
